==> CGFeedMaker-1.0.13.tar.gz: CGFeedMaker/lang/ext/fr_FR.php <==
<?php
$lang['addcategory'] = 'Ajouter une cat&eacute;gorie';
$lang['addedit_feed'] = 'Ajouter/&eacute;diter un flux RSS';
$lang['addfeed'] = 'Ajouter un nouveau flux';
$lang['areyousure_delete'] = 'Etes-vous s&ucirc;r de vouloir supprimer cet &eacute;l&eacute;ment&nbsp;?';
$lang['cancel'] = 'Annuler';
$lang['categories'] = 'Cat&eacute;gories';
$lang['current_value'] = 'Valeur actuelle';
$lang['delete'] = 'Supprimer';
$lang['details'] = 'D&eacute;tails';
$lang['edit'] = 'Editer';
$lang['error_missingparam'] = 'Un param&egrave;tre ou une valeur requis n&#039;ont pu &ecirc;tre trouv&eacute;';
$lang['error_nameexists'] = 'Un &eacute;l&eacute;ment avec ce titre existe d&eacute;j&agrave;';
$lang['error_nocatname'] = 'Merci de sp&eacute;cifier un nom de cat&eacute;gorie';
$lang['error_nonamegiven'] = 'Vous devez donner un nom/alias de flux';
$lang['error_nopermission'] = 'Permission refus&eacute;e';
$lang['error_notemplate'] = 'Pas de gabarit fourni';
$lang['feeds'] = 'Flux';
$lang['feed_copyright'] = 'Copyright du flux';
$lang['feed_description'] = 'Description du flux';
$lang['feed_editor'] = 'Editeur de flux';
$lang['feed_extension'] = 'Extension du flux';
$lang['feed_image'] = 'Image du flux';
$lang['feed_link'] = 'Lien du flux';
$lang['feed_namealias'] = 'Nom/Alias du flux';
$lang['feed_pageid'] = 'Utiliser cette page pour les liens';
$lang['feed_title'] = 'Titre du flux';
$lang['feed_ttl'] = 'Dur&eacute;e de vie';
$lang['friendlyname'] = 'Calguys Feed Maker&nbsp;';
$lang['help'] = '<h3>Que fait ce module ?</h3>
<p>Ce module permet de construire et g&eacute;rer des flux RSS constitu&eacute;s de donn&eacute;es provenant de tout module de CMS Made Simple qui comprend une vue sommaire.</p>
<p>Il permet de cat&eacute;goriser les flux, g&eacute;n&eacute;rer des liens auto-d&eacute;tect&eacute;s, et des liens autonomes (&quot;standalone&quot;) vers les flux RSS.</p>
<p>Les &quot;Pretty URLs&quot; sont prises en charge si votre site les supporte. - <em>ex:</em> http://www.yoursite.com/feeds/Feed-Name</p>
<h3>Comment l&#039;utiliser ?</h3>
<ul>
<li>- D&#039;abord vous devez d&#039;abord cr&eacute;er un nouveau flux, et remplir les param&egrave;tres fournis.
  <p>Un gabarit est associ&eacute; &agrave; chaque flux. Le gabarit par d&eacute;faut montre comment g&eacute;n&eacute;rer un flux RSS depuis le module News.</p>
<p>Pour g&eacute;n&eacute;rer des gabarits d&#039;autres flux que vous aurez besoin d&#039;utiliser des variables de ce module. Mettez get_template_vars () dans une page utilisant ce module pour voir quelles variables vous pouvez appeler dans votre gabarit de flux RSS. Pour contr&ocirc;ler la sortie de votre flux RSS, vous  devez utiliser une combinaison de ces variables et modifier l&#039;appel de votre module dans le gabarit.</p>
</li>
<li>- Ensuite vous devriez placer une balise d&#039;auto-d&eacute;tection &agrave; l&#039;endroit appropri&eacute;.
  <p>Cela cr&eacute;era des liens auto-d&eacute;tect&eacute;s en sortie. Vous pouvez placer cette balise dans la section &quot;head&quot; du gabarit de la page, ou la section m&eacute;tadonn&eacute;es de pages sp&eacute;cifiques pour g&eacute;n&eacute;rer l&#039;auto-d&eacute;tection. On peut sp&eacute;cifier diff&eacute;rents param&egrave;tres afin de contr&ocirc;ler pour quels flux les liens auto-d&eacute;tect&eacute;s sont g&eacute;n&eacute;r&eacute;s.</p>
<p>  
<em>ex1 :</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; feed=&#039;myFeed1,myFeed2 &#039;}</strong> - Cela cr&eacute;e des liens automatique pour tous les flux sp&eacute;cifi&eacute;<br />
<em>ex2 :</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; category=&#039;myCategory1,myCategory2&#039;}</strong> - Cela cr&eacute;e des liens automatique pour tous les flux dans la cat&eacute;gorie ou les cat&eacute;gories</p>
</li>
  <li>- Finalement, vous pouvez placer des liens vers des flux sp&eacute;cifiques dans votre contenu, en utilisant le param&egrave;tre action=rsslink.
<p>Cela cr&eacute;era un lien sp&eacute;cifique &agrave; l&#039;emplacement o&ugrave; vous avez mis l&#039;appel.</p>
  <p><em>ex1 :</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039;}</strong> - Affichage g&eacute;n&eacute;rique &quot;rsslink&quot; 
  <br/>
  <em>ex2 :</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; imageonly=&#039;&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039;}</strong> - Cela affiche un lien qui montre seulement une image pour le lien, elle sp&eacute;cifie une autre image qui a &eacute;t&eacute; transf&eacute;r&eacute;e pour utiliser le lien autre que l&#039;image par d&eacute;faut et il utilise une classe CSS diff&eacute;rente pour le format d&#039;image (pr&eacute;cis&eacute; dans l&#039;une de vos feuilles de style)  
  <br />
   <em>ex3 :</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; text=&#039;RSS News Feed&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039; linkclass=&quot;rssLink&quot;}</strong> - Cela affiche un texte diff&eacute;rent pour le lien vers le flux, il sp&eacute;cifie une nouvelle image &agrave; utiliser et utilise une classe CSS diff&eacute;rente pour le format d&#039;image (pr&eacute;cis&eacute; dans l&#039;une de vos feuilles de style) 
</p>
</ul>
<h3>Notes :</h3>
<ul>
<li>Ce module donnera de meilleurs r&eacute;sultats, et le flux par d&eacute;faut sera valid&eacute; si vous avez configur&eacute; correctement les &quot;Pretty URLs&quot;. Sinon, les liens Atom pouront avoir des probl&egrave;mes avec certaines de vos URL.</li>
</ul>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it :</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org"><calguy1000@cmsmadesimple.org></a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['info_alias'] = 'Ce flux doit contenir uniquement des caract&egrave;res utilisables dans un URL';
$lang['info_copyright'] = 'Note de copyright pour le contenu de ce canal';
$lang['info_description'] = 'Une phrase d&eacute;crivant ce canal';
$lang['info_editor'] = 'Courriel de l&#039;&eacute;diteur de ce canal';
$lang['info_extension'] = 'Feed Extension (sp&eacute;cifier une extension pour ce flux,  i.e xml,rss,kml... s&#039;il n&#039;est pas pr&eacute;cis&eacute; l&#039;extension rss par d&eacute;faut sera utilis&eacute;';
$lang['info_feed_extension'] = 'Lorsque vous utilisez le &quot;mod_rewrite&quot; d&#039;Apache (les pretty URLs) ce param&egrave;tre peut &ecirc;tre utilis&eacute; pour sp&eacute;cifier l&#039;extension des flux g&eacute;n&eacute;r&eacute;s';
$lang['info_image'] = 'Sp&eacute;cifie si une image GIF, JPEG ou PNG peut &ecirc;tre affich&eacute;e dans le canal ';
$lang['info_link'] = 'L&#039;adresse URL vers le site HTML correspondant au canal';
$lang['info_pageid'] = 'La page qui devrait &ecirc;tre utilis&eacute;e pour tous les liens de ce flux';
$lang['info_ttl'] = 'nombre de minutes qui indique combien de temps un canal peut &ecirc;tre mis en cache avant une actualisation depuis la source';
$lang['moddescription'] = 'Un outil flexible pour la cr&eacute;ation et la gestion de flux RSS';
$lang['name'] = 'Nom';
$lang['param_action'] = 'Pr&eacute;cise le comportement du module. Il y a 2 valeurs possibles pour ce param&egrave;tre&nbsp;: &quot;autodiscovery&quot; &amp; &quot;rsslink&quot;. L&#039;action autodiscovery g&eacute;n&egrave;rera des liens auto-d&eacute;tect&eacute;s, et devrait &ecirc;tre utilis&eacute; &agrave; un endroit permettant que le contenu r&eacute;sultant apparaisse dans la section &quot;head&quot; de votre sortie. L&#039;action rsslink peut &ecirc;tre utilis&eacute;e pour cr&eacute;er un lien vers un flux sp&eacute;cifique, et peut &ecirc;tre plac&eacute; dans le contenu de votre page.';
$lang['param_category'] = 'Utilisable uniquement avec l&#039;action autodiscovery, ce param&egrave;tre vous permet de sp&eacute;cifier une liste s&eacute;par&eacute;e par des virgules de cat&eacute;gories de flux qui contr&ocirc;lera pour quels flux les liens sont g&eacute;n&eacute;r&eacute;s.';
$lang['param_feed'] = 'Utilisable avec les actions rsslink et autodiscovery, ce param&egrave;tre vous permet de sp&eacute;cifier pour quel flux g&eacute;n&eacute;rer un lien. Pour l&#039;action autodiscovery, une liste s&eacute;par&eacute;e par des virgules de noms de flux peut &ecirc;tre utilis&eacute;e.';
$lang['param_image'] = 'Utilisable avec l&#039;action rsslink, ce param&egrave;tre vous permet de sp&eacute;cifier une image diff&eacute;rente pour le lien du flux RSS.';
$lang['param_imageclass'] = 'Sp&eacute;cifie une classe CSS pour la balise image d&#039;un lien de flux RSS';
$lang['param_imageonly'] = 'Utilisable avec l&#039;action rsslink, ce param&egrave;tre vous permet de sp&eacute;cifier qu&#039;aucun texte ne devrait appara&icirc;tre avec le lien.';
$lang['param_linkclass'] = 'Sp&eacute;cifie une classe CSS pour la balise lien d&#039;un lien de flux RSS';
$lang['param_urlonly'] = 'Seulement applicable avec l&#039;action rsslink, ce param&egrave;tre n&eacute;cessite que le code ne donne que l&#039;url vers le flux RSS';
$lang['param_text'] = 'Utilisable avec l&#039;action rsslink, ce param&egrave;tre vous permet de sp&eacute;cifier le texte qui devrait &ecirc;tre associ&eacute; au lien. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute;, le titre du flux sera utilis&eacute;.';
$lang['postinstall'] = 'Le module CGFeedMaker a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
$lang['postuninstall'] = 'Le module CGFeedMaker et toutes les donn&eacute;es associ&eacute;es ont &eacute;t&eacute; supprim&eacute;es.';
$lang['really_uninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer ce module ? Toutes les donn&eacute;es associ&eacute;es &agrave; ce module seront supprim&eacute;es.';
$lang['reset_to_factory'] = 'Restaurer les param&egrave;tres par d&eacute;faut';
$lang['settings'] = 'Param&egrave;tres';
$lang['submit'] = 'Soumettre';
$lang['template'] = 'Gabarit';
$lang['template_source'] = 'Source du gabarit';
$lang['utma'] = '156861353.2003866910.1245652859.1276552747.1276574546.150';
$lang['utmz'] = '156861353.1276552748.149.136.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
$lang['qca'] = '4a3d1b41-5eb36-c9570-f49ea';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> CGFeedMaker-1.0.17.tar.gz: CGFeedMaker/lang/ext/fr_FR.php <==
<?php
$lang['addcategory'] = 'Ajouter une cat&eacute;gorie';
$lang['addedit_feed'] = 'Ajouter/&eacute;diter un flux RSS';
$lang['addfeed'] = 'Ajouter un nouveau flux';
$lang['areyousure_delete'] = 'Etes-vous s&ucirc;r de vouloir supprimer cet &eacute;l&eacute;ment&nbsp;?';
$lang['cancel'] = 'Annuler';
$lang['categories'] = 'Cat&eacute;gories';
$lang['current_value'] = 'Valeur actuelle';
$lang['delete'] = 'Supprimer';
$lang['details'] = 'D&eacute;tails';
$lang['edit'] = 'Editer';
$lang['error_missingparam'] = 'Un param&egrave;tre ou une valeur requis n&#039;ont pu &ecirc;tre trouv&eacute;';
$lang['error_nameexists'] = 'Un &eacute;l&eacute;ment avec ce titre existe d&eacute;j&agrave;';
$lang['error_nocatname'] = 'Merci de sp&eacute;cifier un nom de cat&eacute;gorie';
$lang['error_nonamegiven'] = 'Vous devez donner un nom/alias de flux';
$lang['error_nopermission'] = 'Permission refus&eacute;e';
$lang['error_notemplate'] = 'Pas de gabarit fourni';
$lang['feeds'] = 'Flux';
$lang['feed_copyright'] = 'Copyright du flux';
$lang['feed_description'] = 'Description du flux';
$lang['feed_editor'] = 'Editeur de flux';
$lang['feed_extension'] = 'Extension du flux';
$lang['feed_image'] = 'Image du flux';
$lang['feed_link'] = 'Lien du flux';
$lang['feed_namealias'] = 'Nom/Alias du flux';
$lang['feed_pageid'] = 'Utiliser cette page pour les liens';
$lang['feed_title'] = 'Titre du flux';
$lang['feed_ttl'] = 'Dur&eacute;e de vie';
$lang['friendlyname'] = 'Flux RSS (CG)';
$lang['help'] = '<h3>Que fait ce module ?</h3>
<p>Ce module permet de construire et g&eacute;rer des flux RSS constitu&eacute;s de donn&eacute;es provenant de tout module de CMS Made Simple qui comprend une vue sommaire.</p>
<p>Il permet de cat&eacute;goriser les flux, g&eacute;n&eacute;rer des liens auto-d&eacute;tect&eacute;s, et des liens autonomes (&quot;standalone&quot;) vers les flux RSS.</p>
<p>Les &quot;Pretty URLs&quot; sont prises en charge si votre site les supporte. - <em>ex:</em> http://www.yoursite.com/feeds/Feed-Name</p>
<h3>Comment l&#039;utiliser ?</h3>
<ul>
<li>- D&#039;abord vous devez d&#039;abord cr&eacute;er un nouveau flux, et remplir les param&egrave;tres fournis.
  <p>Un gabarit est associ&eacute; &agrave; chaque flux. Le gabarit par d&eacute;faut montre comment g&eacute;n&eacute;rer un flux RSS depuis le module News.</p>
<p>Pour g&eacute;n&eacute;rer des gabarits d&#039;autres flux que vous aurez besoin d&#039;utiliser des variables de ce module. Mettez get_template_vars () dans une page utilisant ce module pour voir quelles variables vous pouvez appeler dans votre gabarit de flux RSS. Pour contr&ocirc;ler la sortie de votre flux RSS, vous  devez utiliser une combinaison de ces variables et modifier l&#039;appel de votre module dans le gabarit.</p>
</li>
<li>- Ensuite vous devriez placer une balise d&#039;auto-d&eacute;tection &agrave; l&#039;endroit appropri&eacute;.
  <p>Cela cr&eacute;era des liens auto-d&eacute;tect&eacute;s en sortie. Vous pouvez placer cette balise dans la section &quot;head&quot; du gabarit de la page, ou la section m&eacute;tadonn&eacute;es de pages sp&eacute;cifiques pour g&eacute;n&eacute;rer l&#039;auto-d&eacute;tection. On peut sp&eacute;cifier diff&eacute;rents param&egrave;tres afin de contr&ocirc;ler pour quels flux les liens auto-d&eacute;tect&eacute;s sont g&eacute;n&eacute;r&eacute;s.</p>
<p>  
<em>ex1 :</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; feed=&#039;myFeed1,myFeed2 &#039;}</strong> - Cela cr&eacute;e des liens automatique pour tous les flux sp&eacute;cifi&eacute;<br />
<em>ex2 :</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; category=&#039;myCategory1,myCategory2&#039;}</strong> - Cela cr&eacute;e des liens automatique pour tous les flux dans la cat&eacute;gorie ou les cat&eacute;gories</p>
</li>
  <li>- Finalement, vous pouvez placer des liens vers des flux sp&eacute;cifiques dans votre contenu, en utilisant le param&egrave;tre action=rsslink.
<p>Cela cr&eacute;era un lien sp&eacute;cifique &agrave; l&#039;emplacement o&ugrave; vous avez mis l&#039;appel.</p>
  <p><em>ex1 :</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039;}</strong> - Affichage g&eacute;n&eacute;rique &quot;rsslink&quot; 
  <br/>
  <em>ex2 :</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; imageonly=&#039;&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039;}</strong> - Cela affiche un lien qui montre seulement une image pour le lien, elle sp&eacute;cifie une autre image qui a &eacute;t&eacute; transf&eacute;r&eacute;e pour utiliser le lien autre que l&#039;image par d&eacute;faut et il utilise une classe CSS diff&eacute;rente pour le format d&#039;image (pr&eacute;cis&eacute; dans l&#039;une de vos feuilles de style)  
  <br />
   <em>ex3 :</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; text=&#039;RSS News Feed&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039; linkclass=&quot;rssLink&quot;}</strong> - Cela affiche un texte diff&eacute;rent pour le lien vers le flux, il sp&eacute;cifie une nouvelle image &agrave; utiliser et utilise une classe CSS diff&eacute;rente pour le format d&#039;image (pr&eacute;cis&eacute; dans l&#039;une de vos feuilles de style) 
</p>
</ul>
<h3>Notes :</h3>
<ul>
<li>Ce module donnera de meilleurs r&eacute;sultats, et le flux par d&eacute;faut sera valid&eacute; si vous avez configur&eacute; correctement les &quot;Pretty URLs&quot;. Sinon, les liens Atom pouront avoir des probl&egrave;mes avec certaines de vos URL.</li>
</ul>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it :</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org"><calguy1000@cmsmadesimple.org></a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['info_alias'] = 'Ce flux doit contenir uniquement des caract&egrave;res utilisables dans un URL';
$lang['info_copyright'] = 'Note de copyright pour le contenu de ce canal';
$lang['info_description'] = 'Une phrase d&eacute;crivant ce canal';
$lang['info_editor'] = 'Courriel de l&#039;&eacute;diteur de ce canal';
$lang['info_extension'] = 'Feed Extension (sp&eacute;cifier une extension pour ce flux,  i.e xml,rss,kml... s&#039;il n&#039;est pas pr&eacute;cis&eacute; l&#039;extension rss par d&eacute;faut sera utilis&eacute;';
$lang['info_feed_extension'] = 'Lorsque vous utilisez le &quot;mod_rewrite&quot; d&#039;Apache (les pretty URLs) ce param&egrave;tre peut &ecirc;tre utilis&eacute; pour sp&eacute;cifier l&#039;extension des flux g&eacute;n&eacute;r&eacute;s';
$lang['info_image'] = 'Sp&eacute;cifie si une image GIF, JPEG ou PNG peut &ecirc;tre affich&eacute;e dans le canal ';
$lang['info_link'] = 'L&#039;adresse URL vers le site HTML correspondant au canal';
$lang['info_pageid'] = 'La page qui devrait &ecirc;tre utilis&eacute;e pour tous les liens de ce flux';
$lang['info_ttl'] = 'nombre de minutes qui indique combien de temps un canal peut &ecirc;tre mis en cache avant une actualisation depuis la source';
$lang['moddescription'] = 'Un outil flexible pour la cr&eacute;ation et la gestion de flux RSS';
$lang['name'] = 'Nom';
$lang['param_action'] = 'Pr&eacute;cise le comportement du module. Il y a 2 valeurs possibles pour ce param&egrave;tre&nbsp;: &quot;autodiscovery&quot; &amp; &quot;rsslink&quot;. L&#039;action autodiscovery g&eacute;n&egrave;rera des liens auto-d&eacute;tect&eacute;s, et devrait &ecirc;tre utilis&eacute; &agrave; un endroit permettant que le contenu r&eacute;sultant apparaisse dans la section &quot;head&quot; de votre sortie. L&#039;action rsslink peut &ecirc;tre utilis&eacute;e pour cr&eacute;er un lien vers un flux sp&eacute;cifique, et peut &ecirc;tre plac&eacute; dans le contenu de votre page.';
$lang['param_category'] = 'Utilisable uniquement avec l&#039;action autodiscovery, ce param&egrave;tre vous permet de sp&eacute;cifier une liste s&eacute;par&eacute;e par des virgules de cat&eacute;gories de flux qui contr&ocirc;lera pour quels flux les liens sont g&eacute;n&eacute;r&eacute;s.';
$lang['param_feed'] = 'Utilisable avec les actions rsslink et autodiscovery, ce param&egrave;tre vous permet de sp&eacute;cifier pour quel flux g&eacute;n&eacute;rer un lien. Pour l&#039;action autodiscovery, une liste s&eacute;par&eacute;e par des virgules de noms de flux peut &ecirc;tre utilis&eacute;e.';
$lang['param_image'] = 'Utilisable avec l&#039;action rsslink, ce param&egrave;tre vous permet de sp&eacute;cifier une image diff&eacute;rente pour le lien du flux RSS.';
$lang['param_imageclass'] = 'Sp&eacute;cifie une classe CSS pour la balise image d&#039;un lien de flux RSS';
$lang['param_imageonly'] = 'Utilisable avec l&#039;action rsslink, ce param&egrave;tre vous permet de sp&eacute;cifier qu&#039;aucun texte ne devrait appara&icirc;tre avec le lien.';
$lang['param_linkclass'] = 'Sp&eacute;cifie une classe CSS pour la balise lien d&#039;un lien de flux RSS';
$lang['param_urlonly'] = 'Seulement applicable avec l&#039;action rsslink, ce param&egrave;tre n&eacute;cessite que le code ne donne que l&#039;url vers le flux RSS';
$lang['param_text'] = 'Utilisable avec l&#039;action rsslink, ce param&egrave;tre vous permet de sp&eacute;cifier le texte qui devrait &ecirc;tre associ&eacute; au lien. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute;, le titre du flux sera utilis&eacute;.';
$lang['postinstall'] = 'Le module CGFeedMaker a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
$lang['postuninstall'] = 'Le module CGFeedMaker et toutes les donn&eacute;es associ&eacute;es ont &eacute;t&eacute; supprim&eacute;es.';
$lang['really_uninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer ce module ? Toutes les donn&eacute;es associ&eacute;es &agrave; ce module seront supprim&eacute;es.';
$lang['reset_to_factory'] = 'Restaurer les param&egrave;tres par d&eacute;faut';
$lang['settings'] = 'Param&egrave;tres';
$lang['submit'] = 'Soumettre';
$lang['template'] = 'Gabarit';
$lang['template_source'] = 'Source du gabarit';
$lang['utmz'] = '156861353.1300521323.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-2066415722-1300533676093';
$lang['utma'] = '156861353.1283075913.1300521323.1301054358.1301063008.14';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
